@@ -1,4 +1,4 @@
-from PyObjCTools.TestSupport import TestCase, min_os_level, expectedFailure
+from PyObjCTools.TestSupport import TestCase, min_os_level
 import CoreML
 
 
@@ -21,6 +21,5 @@ class TestMLModelConfiguration(TestCase):
             CoreML.MLModelConfiguration.setAllowLowPrecisionAccumulationOnGPU_, 0
         )
 
-    @expectedFailure
     def test_methods10_15_missing(self):
         self.assertResultIsBOOL(CoreML.MLModelDescription.isUpdatable)
